//
//  Modal.swift
//  GoldWars
//
//  Created by Niko Jochim on 01.05.20.
//  Copyright © 2020 SP2. All rights reserved.
//

import GameplayKit

class Modal: GKEntity{
    
    var unitCount:Int
    
    init(modaltype: ModalType, base: Base, anchorPoint: CGPoint, entityManager: EntityManager, gameScene: SKScene) {
        unitCount = base.unitCount
        super.init()
        switch modaltype{
        case .BaseDetails:
            addComponent(ModalBackgroundComponent(anchorPoint: anchorPoint))
            addComponent(ModalContentComponent(header: "Basis Information", body: "Diese Basis enthält \(base.unitCount) Einheiten", footer: "", anchorPoint: anchorPoint))
            addComponent(ButtonComponent(iconName: "", text: "Zurück", position: CGPoint(x: anchorPoint.x , y: anchorPoint.y - 120), isEnabled: true, onButtonPress: {
                self.removeModalEntities(entityManager: entityManager, gameScene: gameScene)
            }))
        case .BaseAttack:
            addComponent(ModalBackgroundComponent(anchorPoint: anchorPoint))
            addComponent(SliderComponent(width: 300, position: CGPoint(x: anchorPoint.x , y: anchorPoint.y - 50)))
            addComponent(ModalContentComponent(header: "Angriff", body: "Schicke \(unitCount / 2) Einheiten",
                footer: "", anchorPoint: anchorPoint))
            addComponent(ButtonComponent(iconName: "", text: "Senden", position: CGPoint(x: anchorPoint.x , y: anchorPoint.y - 120), isEnabled: true, onButtonPress: {
                self.removeModalEntities(entityManager: entityManager, gameScene: gameScene)
            }))
        }
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func removeModalEntities(entityManager: EntityManager, gameScene: SKScene){
        for entity in entityManager.entities {
            if entityManager.isModal && entity.isMember(of: Modal.self) {
                entityManager.remove(entity)
            }
            for child in gameScene.children {
                if(child.name != "fire"){
                    child.alpha = 1
                }
            }
        }
    }
}
